@@ -104,7 +104,7 @@ load_normal (const gchar *filename, ClutterActor *texture)
 
   if (error)
   {
-    g_warning (error->message);
+    g_warning ("%s", error->message);
     g_error_free (error);
     return;
   }
@@ -155,7 +155,7 @@ load_stretched (const gchar *filename, ClutterActor *texture)
                                               &error);
   if (error)
   {
-    g_warning (error->message);
+    g_warning ("%s", error->message);
     g_error_free (error);
   }
 
@@ -182,7 +182,7 @@ load_centred (const gchar *filename, ClutterActor *texture)
 
   if (error)
   {
-    g_warning (error->message);
+    g_warning ("%s", error->message);
     g_error_free (error);
     return;
   }
@@ -217,7 +217,7 @@ load_scaled (const gchar *filename, ClutterActor *texture)
                                               &error);
   if (error)
   {
-    g_warning (error->message);
+    g_warning ("%s", error->message);
     g_error_free (error);
   }
 
@@ -271,7 +271,7 @@ load_wallpaper (const gchar *filename, ClutterActor *texture)
 
   if (error)
   {
-    g_warning (error->message);
+    g_warning ("%s", error->message);
     g_error_free (error);
     return;
   }
@@ -365,7 +365,7 @@ save_blur (LauncherBackground *bg)
 static gboolean
 create_blur (LauncherBackground *bg)
 {
-#define BLUR_RADIUS 20
+#define BLUR_RADIUS 55
 #define P_WIDTH 320
 #define P_HEIGHT 240
   LauncherBackgroundPrivate *priv;
@@ -466,8 +466,10 @@ on_blur_made (BgClosure *data)
                                 data->pixbuf, NULL);
     clutter_actor_get_scale (CLUTTER_ACTOR (data->bg), &scale, &scale);
     
-    if (scale != 1.0)
+    if (scale > 1.1)
+    {
       clutter_actor_set_opacity (priv->blurred, 255);
+    }
     
     save_blur (data->bg);
 
@@ -486,7 +488,7 @@ on_blur_made (BgClosure *data)
 static gpointer
 threaded_blur (BgClosure *data)
 {
-#define BLUR_RADIUS 20
+#define BLUR_RADIUS 55
 #define P_WIDTH 320
 #define P_HEIGHT 240
   GdkPixbuf *pixbuf, *blurred;
@@ -599,6 +601,7 @@ ensure_layout (LauncherBackground *bg)
   if (!load_blur (bg))
   {
     clutter_actor_set_opacity (priv->blurred, 0);
+    clutter_texture_set_pixbuf (CLUTTER_TEXTURE (priv->blurred), NULL, NULL);
     if (priv->timeout)
       g_source_remove (priv->timeout);
     
