@@ -143,7 +143,7 @@ on_add_clicked (ClutterActor       *actor,
                                      0,
                                      GTK_MESSAGE_WARNING,
                                      GTK_BUTTONS_CLOSE,
-                                     msg_text);
+                                     msg_text, NULL);
     g_free (msg_text);
 
     g_object_set (dialog, 
@@ -201,6 +201,7 @@ on_drop (ClutterActor       *stage,
 
   launcher_menu_set_categories (launcher_menu_get_default (), new_order);
 
+  launcher_category_reset_after_drag (LAUNCHER_CATEGORY (priv->context));
   clutter_ungrab_pointer ();
   g_signal_handlers_disconnect_by_func (stage, on_drag, bar);
   g_signal_handlers_disconnect_by_func (stage, on_drop, bar);
@@ -670,10 +671,10 @@ launcher_catbar_init (LauncherCatbar *catbar)
   LauncherCatbarPrivate *priv;
   LauncherMenu *menu = launcher_menu_get_default ();
   LauncherConfig *cfg = launcher_config_get_default ();
-  ClutterActor *shadow;
   ClutterAlpha *alpha;
   ClutterFocusManager *manager = CLUTTER_FOCUS_MANAGER (clutter_focus_manager_get_default ());
   gint cat_height = cfg->cat_height;
+  ClutterActor *shadow;
 
   priv = catbar->priv = LAUNCHER_CATBAR_GET_PRIVATE (catbar);
 
@@ -687,9 +688,10 @@ launcher_catbar_init (LauncherCatbar *catbar)
   clutter_container_add_actor (CLUTTER_CONTAINER (catbar), shadow);
   clutter_actor_set_size (shadow, CSW()+20, cat_height+10);
   clutter_actor_set_position (shadow, -10, PANEL_HEIGHT-5);
-  clutter_actor_show (shadow);
+  if (!cfg->new_theme)
+    clutter_actor_show (shadow);
 
-  priv->bg =launcher_util_texture_new_from_file (PKGDATADIR"/catbarbg.svg");
+  priv->bg =launcher_util_texture_new_from_file (cfg->catbarbg);
   clutter_container_add_actor (CLUTTER_CONTAINER (catbar), priv->bg);
   clutter_actor_set_size (priv->bg, CSW (), cat_height);
   clutter_actor_set_position (priv->bg, 0, PANEL_HEIGHT);
@@ -698,11 +700,11 @@ launcher_catbar_init (LauncherCatbar *catbar)
 
   priv->add = launcher_add_new ();
   clutter_container_add_actor (CLUTTER_CONTAINER (catbar), priv->add);
-  clutter_actor_set_size (priv->add, cat_height/3, cat_height/3);
+  clutter_actor_set_size (priv->add, cat_height/4, cat_height/4);
   clutter_actor_set_anchor_point_from_gravity (priv->add, 
                                                CLUTTER_GRAVITY_CENTER);
   clutter_actor_set_position (priv->add, 
-                              CSW()-(CAW(priv->add)*1),
+                              CSW()-((CSW()/8)/2),
                               (cat_height/2)+PANEL_HEIGHT);
   clutter_actor_show (priv->add);
   clutter_actor_set_reactive (priv->add, TRUE);
