@@ -42,9 +42,14 @@ G_DEFINE_TYPE (LauncherCategory, launcher_category, CLUTTER_TYPE_DRAG_DEST);
   LAUNCHER_TYPE_CATEGORY, \
   LauncherCategoryPrivate))
 
+#define BG_INACTIVE 0
+#define BG_ACTIVE 150
+
+
 static ClutterTimeline       *main_time = NULL;
 static ClutterEffectTemplate *main_temp = NULL;
 static ClutterActor          *bg_texture = NULL;
+static ClutterActor          *bgv_texture = NULL;
 static ClutterActor          *i_texture = NULL;
 
 struct _LauncherCategoryPrivate
@@ -52,6 +57,7 @@ struct _LauncherCategoryPrivate
   LauncherMenuCategory *cat;
 
   ClutterActor *bg;
+  ClutterActor *bgv;
   ClutterActor *hilight;
   ClutterActor *icon;
   ClutterActor *text;
@@ -124,6 +130,7 @@ launcher_category_set_active (LauncherCategory *cat,
   }
 
   clutter_effect_fade (main_temp, priv->bg, alpha, NULL, NULL);
+  clutter_actor_set_opacity (priv->bgv, 0);
   
   clutter_effect_fade (main_temp, priv->toggle, alpha, NULL, NULL);
   clutter_label_set_color (CLUTTER_LABEL (priv->text), text_col);
@@ -149,7 +156,7 @@ on_enter (ClutterActor *bg,
     g_object_unref (priv->timeline);
   }
 
-  priv->timeline = clutter_effect_fade (main_temp, priv->bg, 100, NULL, NULL);
+  priv->timeline = clutter_effect_fade (main_temp, priv->bg, 255, NULL, NULL);
   clutter_effect_fade (main_temp, priv->toggle, 255, NULL, NULL);
 
   return TRUE;
@@ -438,21 +445,50 @@ on_open_clicked (ClutterActor       *actor,
 
 }
 
+
+static gboolean
+on_hi_enter (ClutterActor *actor, ClutterEvent *event)
+{
+  clutter_actor_set_opacity (actor, 30);
+  return FALSE;
+}
+
+static gboolean
+on_hi_leave (ClutterActor *actor, ClutterEvent *event)
+{
+  clutter_actor_set_opacity (actor, 0);
+  return FALSE;
+}
 static ClutterActor *
 make_item (const gchar *name, const gchar *icon_name, gint width, gint height)
 {
   LauncherConfig *cfg = launcher_config_get_default ();
-  ClutterActor *bg, *icon, *group, *label;
+  ClutterActor *bg, *hi, *icon, *group, *label;
+  ClutterColor black = { 0xff, 0xff, 0xff, 0x22 };
 
   bg = clutter_group_new ();
   clutter_actor_set_size (bg, width, height);
   clutter_actor_show (bg);
-  
+
+  if (cfg->new_theme)
+  {
+    hi = clutter_rectangle_new_with_color (&black);
+    clutter_container_add_actor (CLUTTER_CONTAINER (bg), hi);
+    clutter_actor_set_position (hi, -1, 0);
+    clutter_actor_set_size (hi, width, height);
+    clutter_actor_set_opacity (hi, 0);
+    clutter_actor_set_reactive (hi, TRUE);
+    clutter_actor_show (hi);
+
+    g_signal_connect (hi, "enter-event", G_CALLBACK (on_hi_enter), NULL);
+    g_signal_connect (hi, "leave-event", G_CALLBACK (on_hi_leave), NULL);
+  }
+ 
   icon = launcher_util_texture_new_from_named_icon (icon_name);
   clutter_container_add_actor (CLUTTER_CONTAINER (bg), icon);
   clutter_actor_set_size (icon, height * 0.80, height * 0.80);
   clutter_actor_set_anchor_point_from_gravity (icon, CLUTTER_GRAVITY_CENTER);
-  clutter_actor_set_position (icon, height/2, height/2);
+  clutter_actor_set_position (icon, height/1.5, height/2);
   clutter_actor_show (icon);
 
   group = clutter_group_new ();
@@ -469,6 +505,12 @@ make_item (const gchar *name, const gchar *icon_name, gint width, gint height)
   clutter_actor_set_position (label, 0, - (CAH (label)/2));
   clutter_actor_show (label);
 
+
+  if (cfg->new_theme)
+  {
+    clutter_actor_hide (icon);
+    clutter_actor_set_position (group, height * 0.30, height/2);
+  }
   return bg;
 }
 
@@ -478,6 +520,8 @@ on_toggle_clicked (ClutterActor *close,
                    LauncherCategory *cat)
 {
   LauncherCategoryPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
+  gint ih;
     
   g_return_val_if_fail (LAUNCHER_IS_CATEGORY (cat), FALSE);
   priv = cat->priv;
@@ -489,6 +533,8 @@ on_toggle_clicked (ClutterActor *close,
   {
     ClutterActor *bg, *item;
 
+    ih = cfg->cat_height/4;
+
     priv->options = clutter_group_new ();
     clutter_container_add_actor (CLUTTER_CONTAINER (cat), priv->options);
     clutter_actor_set_size (priv->options, CAW (cat), CAH (cat));
@@ -498,44 +544,55 @@ on_toggle_clicked (ClutterActor *close,
     clutter_actor_set_opacity (priv->options, 0);
     clutter_actor_show (priv->options);
 
-    bg = item = launcher_util_texture_new_from_file (PKGDATADIR"/options.svg");
-    clutter_actor_set_size (bg, CAW (cat)*0.98, CAH (cat) * 0.75);
-    clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), bg);
-    clutter_actor_set_anchor_point_from_gravity (bg, CLUTTER_GRAVITY_NORTH);
-    clutter_actor_set_position (bg, CAW (cat)/2, CAH (cat) *0.2);
-    clutter_actor_show (bg);
-
+    if (cfg->new_theme)
+    {
+      bg = item=launcher_util_texture_new_from_file (cfg->catbg);
+      clutter_actor_set_size (bg, cfg->cat_width, cfg->cat_height);
+      clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), bg);
+      clutter_actor_set_anchor_point_from_gravity (bg, CLUTTER_GRAVITY_NORTH);
+      clutter_actor_set_position (bg, CAW (cat)/2, 0);
+      clutter_actor_show (bg);
+     }
+    else
+    {
+      bg = item=launcher_util_texture_new_from_file (cfg->options);
+      clutter_actor_set_size (bg, CAW (cat)*0.98, CAH (cat) - (ih*1));
+      clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), bg);
+      clutter_actor_set_anchor_point_from_gravity (bg, CLUTTER_GRAVITY_NORTH);
+      clutter_actor_set_position (bg, CAW (cat)/2, ih * 0.9);
+      clutter_actor_show (bg);
+    }
     clutter_actor_show (item);
 
     item = make_item (priv->active ? _("Close") :_("Open"), 
                       priv->active ? "gtk-close" : "gtk-open",
-                      CAW (bg), CAH (bg)/3);
+                      cfg->cat_width, ih*0.9);
     clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), item);
     clutter_actor_set_position (item, 
                                 CAW (cat) * 0.01,
-                                clutter_actor_get_y (bg));
+                                ih * 1);
     clutter_actor_show (item);
     clutter_actor_set_reactive (item, TRUE);
     g_signal_connect (item, "button-release-event",
                       G_CALLBACK (on_open_clicked), cat);
 
     item = make_item (_("Edit"), "gtk-properties",
-                      CAW (bg), CAH (bg)/3);
+                      cfg->cat_width, ih*0.9);
     clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), item);
     clutter_actor_set_position (item, 
                                 CAW (cat) * 0.01,
-                                clutter_actor_get_y (bg) + CAH (bg)/3);
+                                ih*2);
     clutter_actor_show (item);
     clutter_actor_set_reactive (item, TRUE);
     g_signal_connect (item, "button-release-event",
                       G_CALLBACK (on_edit_clicked), cat);
 
     item = make_item (_("Delete"), "gtk-delete",
-                      CAW (bg), CAH (bg)/3);
+                      cfg->cat_width, ih*0.9);
     clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), item);
     clutter_actor_set_position (item, 
                                 CAW (cat) * 0.01,
-                                clutter_actor_get_y (bg) + ((CAH (bg)/3)*2));
+                                ih * 3);
     clutter_actor_show (item);
     clutter_actor_set_reactive (item, TRUE);
     g_signal_connect (item, "button-release-event",
@@ -549,11 +606,29 @@ on_toggle_clicked (ClutterActor *close,
   return TRUE;
 }
 
+static gboolean
+button_press (ClutterActor       *actor, 
+              ClutterButtonEvent *event, 
+              LauncherCategory   *cat)
+{
+  g_return_val_if_fail (LAUNCHER_IS_CATEGORY (cat), FALSE);
+
+  clutter_actor_set_opacity (cat->priv->bgv, BG_ACTIVE);
+  clutter_actor_set_opacity (cat->priv->bg, BG_INACTIVE);
+
+  return TRUE;
+}
+
 static gboolean
 show_menu (ClutterActor       *actor,
            ClutterButtonEvent *event,
            LauncherCategory   *cat)
 {
+  g_return_val_if_fail (LAUNCHER_IS_CATEGORY (cat), FALSE);
+
+  clutter_actor_set_opacity (cat->priv->bg, BG_ACTIVE);
+  clutter_actor_set_opacity (cat->priv->bgv, BG_INACTIVE);  
+  
   if (event->button != 3)
   {
     return FALSE;
@@ -575,9 +650,6 @@ launcher_category_set_menu_category (LauncherCategory     *cat,
   gint cat_width = cfg->cat_width;
   gint cat_height = cfg->cat_height;
   gint cat_padding = cfg->cat_padding;
-  ClutterActor *sep;
-  ClutterColor black = { 0x00, 0x00, 0x00, 0xff };
-  ClutterColor white = { 0xff, 0xff, 0xff, 0xff };
   
   g_return_if_fail (LAUNCHER_IS_CATEGORY (cat));
   g_return_if_fail (category);
@@ -597,29 +669,45 @@ launcher_category_set_menu_category (LauncherCategory     *cat,
   clutter_actor_set_reactive (priv->bg, TRUE);
   g_signal_connect (priv->bg, "enter-event", G_CALLBACK (on_enter), cat);
   g_signal_connect (priv->bg, "leave-event", G_CALLBACK (on_leave), cat);
+  g_signal_connect (priv->bg, "button-press-event", 
+                    G_CALLBACK (button_press), cat);
   g_signal_connect (priv->bg, "button-release-event", 
                     G_CALLBACK (show_menu), cat);
 
-  /* Vsep */
-  sep = clutter_rectangle_new_with_color (&black);
-  clutter_container_add_actor (CLUTTER_CONTAINER (cat), sep);
-  clutter_actor_set_size (sep, 1, cat_height);
-  clutter_actor_set_position (sep, cat_width-1, 0);
-  clutter_actor_set_opacity (sep, 50);
-  clutter_actor_show (sep);
+  priv->bgv = tidy_texture_frame_new (CLUTTER_TEXTURE (bgv_texture), 
+                                     2, 2, 2, 2);
+  clutter_container_add_actor (CLUTTER_CONTAINER (cat), priv->bgv);
+  clutter_actor_set_size (priv->bgv, cat_width, cat_height);
+  clutter_actor_set_position (priv->bgv, 0, 0);
+  clutter_actor_set_opacity (priv->bgv, 0);
+  clutter_actor_show (priv->bgv);
 
-  sep = clutter_rectangle_new_with_color (&white);
-  clutter_container_add_actor (CLUTTER_CONTAINER (cat), sep);
-  clutter_actor_set_size (sep, 1, cat_height);
-  clutter_actor_set_position (sep, cat_width, 0);
-  clutter_actor_set_opacity (sep, 50);
-  clutter_actor_show (sep);
+  if (!cfg->new_theme)
+  {
+    ClutterActor *sep;
+    ClutterColor black = { 0x00, 0x00, 0x00, 0xff };
+    ClutterColor white = { 0xff, 0xff, 0xff, 0xff };
+
+    sep = clutter_rectangle_new_with_color (&black);
+    clutter_container_add_actor (CLUTTER_CONTAINER (cat), sep);
+    clutter_actor_set_size (sep, 1, cat_height);
+    clutter_actor_set_position (sep, cat_width-1, 0);
+    clutter_actor_set_opacity (sep, 50);
+    clutter_actor_show (sep);
+
+    sep = clutter_rectangle_new_with_color (&white);
+    clutter_container_add_actor (CLUTTER_CONTAINER (cat), sep);
+    clutter_actor_set_size (sep, 1, cat_height);
+    clutter_actor_set_position (sep, cat_width, 0);
+    clutter_actor_set_opacity (sep, 50);
+    clutter_actor_show (sep);
+  }
 
   /* Category */
   priv->icon = clutter_texture_new_from_pixbuf (
                                     launcher_menu_category_get_icon (category));
   clutter_container_add_actor (CLUTTER_CONTAINER (cat), priv->icon);
-  pos = (cat_height - CAT_ICON_SIZE()) / 2;
+  pos = (cat_height - CAT_ICON_SIZE()) / 3;
   clutter_actor_set_position (priv->icon, 
                               (cat_width - CAT_ICON_SIZE())/2, 
                               pos - (cat_padding*1.5));
@@ -642,7 +730,7 @@ launcher_category_set_menu_category (LauncherCategory     *cat,
    clutter_actor_set_width (priv->text, cat_width);
   clutter_actor_set_position (priv->text, 
                               (cat_width-CAW (priv->text))/2,
-                              pos + CAH(priv->icon));
+                              pos * 1.3 + CAH(priv->icon));
   clutter_actor_show (priv->text);
 
   /* Info icon */
@@ -686,6 +774,15 @@ launcher_category_set_flipped(LauncherCategory *cat, gboolean flipped)
     rotate (cat); 
 }
 
+void
+launcher_category_reset_after_drag (LauncherCategory *cat)
+{
+  g_return_if_fail (LAUNCHER_IS_CATEGORY (cat));
+
+  clutter_actor_set_opacity (cat->priv->bg, BG_ACTIVE);
+  clutter_actor_set_opacity (cat->priv->bgv, BG_INACTIVE);
+}
+
 /* GObject stuff */
 static void
 launcher_category_finalize (GObject *category)
@@ -731,6 +828,7 @@ static void
 launcher_category_init (LauncherCategory *category)
 {
   LauncherCategoryPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
   ClutterAlpha *alpha;
 
   priv = category->priv = LAUNCHER_CATEGORY_GET_PRIVATE (category);
@@ -750,12 +848,17 @@ launcher_category_init (LauncherCategory *category)
   if (CLUTTER_IS_TEXTURE (bg_texture))
     g_object_ref (bg_texture);
   else
-    bg_texture = launcher_util_texture_new_from_file (PKGDATADIR"/catbg.svg");
+    bg_texture = launcher_util_texture_new_from_file (cfg->catbg);
+
+  if (CLUTTER_IS_TEXTURE (bgv_texture))
+    g_object_ref (bgv_texture);
+  else
+    bgv_texture = launcher_util_texture_new_from_file (cfg->catbgv);
 
   if (CLUTTER_IS_TEXTURE (i_texture))
     g_object_ref (i_texture);
   else
-    i_texture = launcher_util_texture_new_from_file (PKGDATADIR"/info.svg");
+    i_texture = launcher_util_texture_new_from_file (cfg->info);
 
   clutter_drag_dest_enable (CLUTTER_DRAG_DEST (category));
 
