@@ -47,8 +47,14 @@ G_DEFINE_TYPE (LauncherIcon, launcher_icon, CLUTTER_TYPE_GROUP);
   LauncherIconPrivate))
 
 #define BG_PADDING 5
+#define BG_INACTIVE ((cfg->bg_inactive))
+#define BG_ACTIVE ((cfg->bg_active))
 
 static ClutterActor *bg_texture = NULL;
+static ClutterActor *bgv_texture = NULL;
+
+static ClutterActor *bg_corners[] = { NULL, NULL, NULL, NULL };
+static ClutterActor *bgv_corners[] = { NULL, NULL, NULL, NULL };
 
 struct _LauncherIconPrivate
 {
@@ -66,6 +72,7 @@ struct _LauncherIconPrivate
   ClutterTimeline       *current;
 
   ClutterActor *bg;
+  ClutterActor *bgv;
   ClutterActor *label;
   ClutterActor *texture;
   ClutterActor *clone;
@@ -159,7 +166,7 @@ on_motion (ClutterActor       *actor,
 
   if (event->modifier_state & CLUTTER_BUTTON1_MASK)
   {
-    if (priv->clone)
+    if (CLUTTER_IS_ACTOR (priv->clone))
     {
       clutter_actor_destroy (priv->clone);
     }
@@ -191,11 +198,24 @@ on_app_clicked (ClutterActor       *actor,
                 LauncherIcon       *icon)
 {
   LauncherIconPrivate *priv;
-  gint icon_width = (launcher_config_get_default ())->icon_width;
+  LauncherConfig *cfg = launcher_config_get_default ();
+  gint icon_width = cfg->icon_width;
 
   g_return_val_if_fail (LAUNCHER_IS_ICON (icon), FALSE);
   priv = icon->priv;
 
+  if (event->type == CLUTTER_BUTTON_PRESS)
+  {
+    clutter_actor_set_opacity (priv->bgv, BG_ACTIVE);
+    clutter_actor_set_opacity (priv->bg, BG_INACTIVE);
+    return TRUE;
+  }
+  else
+  {
+    clutter_actor_set_opacity (priv->bg, BG_ACTIVE);
+    clutter_actor_set_opacity (priv->bgv, BG_INACTIVE);
+  }
+
   if (event->button == 1)
     ;
   else if (event->button == 3)
@@ -251,6 +271,7 @@ on_enter (ClutterActor          *actor,
           LauncherIcon          *icon)
 {
   LauncherIconPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
 
   g_return_val_if_fail (LAUNCHER_IS_ICON (icon), FALSE);
   priv = icon->priv;
@@ -263,11 +284,12 @@ on_enter (ClutterActor          *actor,
   }
 
   clutter_effect_fade (priv->temp, priv->toggle, 255, NULL, NULL);
-  clutter_effect_fade (priv->temp, priv->bg, 130, NULL, NULL);
+  clutter_effect_fade (priv->temp, priv->bg, BG_ACTIVE, NULL, NULL);
   
   if (priv->tooltip)
   {
-    clutter_actor_set_position (priv->tooltip, event->x, event->y);
+    clutter_actor_set_position (priv->tooltip, 
+                                event->x, event->y);
     priv->show_tooltip = TRUE;
     g_timeout_add (400, (GSourceFunc)tooltip_timeout, icon);
   }
@@ -281,6 +303,7 @@ on_leave (ClutterActor          *actor,
           LauncherIcon          *icon)
 {
   LauncherIconPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
 
   g_return_val_if_fail (LAUNCHER_IS_ICON (icon), FALSE);
   priv = icon->priv;
@@ -291,8 +314,11 @@ on_leave (ClutterActor          *actor,
     clutter_timeline_stop (priv->current);
     g_object_unref (priv->current);
   }
+  if (priv->flipped && !clutter_timeline_is_playing (priv->slow_time))
+    return TRUE;
+
   clutter_effect_fade (priv->temp, priv->toggle,  0, NULL, NULL);
-  clutter_effect_fade (priv->temp, priv->bg, 50, NULL, NULL);
+  clutter_effect_fade (priv->temp, priv->bg, BG_INACTIVE, NULL, NULL);
 
   if (priv->tooltip)
     clutter_effect_fade (priv->temp, priv->tooltip, 0, NULL, NULL);    
@@ -404,7 +430,9 @@ rotate (LauncherIcon *icon)
   LauncherIconPrivate *priv = icon->priv;
 
   if (!clutter_timeline_is_playing (priv->slow_time))
+  {
     clutter_timeline_start (priv->slow_time);
+  }
 } 
 
 static gboolean
@@ -571,21 +599,50 @@ on_delete_clicked (ClutterActor       *actor,
   return TRUE;
 }
 
+static gboolean
+on_hi_enter (ClutterActor *actor, ClutterEvent *event)
+{
+  clutter_actor_set_opacity (actor, 30);
+  return FALSE;
+}
+
+static gboolean
+on_hi_leave (ClutterActor *actor, ClutterEvent *event)
+{
+  clutter_actor_set_opacity (actor, 0);
+  return FALSE;
+}
+
 static ClutterActor *
 make_item (const gchar *name, const gchar *icon_name, gint width, gint height)
 {
   LauncherConfig *cfg = launcher_config_get_default ();
-  ClutterActor *bg, *icon, *group, *label;
+  ClutterActor *bg, *hi, *icon, *group, *label;
+  ClutterColor black = { 0xff, 0xff, 0xff, 0x22 };
 
   bg = clutter_group_new ();
   clutter_actor_set_size (bg, width, height);
-  clutter_actor_show (bg);
+  clutter_actor_show (bg);  
+
+  if (cfg->new_theme)
+  {
+    hi = clutter_rectangle_new_with_color (&black);
+    clutter_container_add_actor (CLUTTER_CONTAINER (bg), hi);
+    clutter_actor_set_position (hi, 0, 0);
+    clutter_actor_set_size (hi, width, height);
+    clutter_actor_set_opacity (hi, 0);
+    clutter_actor_set_reactive (hi, TRUE);
+    clutter_actor_show (hi);
+
+    g_signal_connect (hi, "enter-event", G_CALLBACK (on_hi_enter), NULL);
+    g_signal_connect (hi, "leave-event", G_CALLBACK (on_hi_leave), NULL);
+  }
   
   icon = launcher_util_texture_new_from_named_icon (icon_name);
   clutter_container_add_actor (CLUTTER_CONTAINER (bg), icon);
   clutter_actor_set_size (icon, height * 0.80, height * 0.80);
   clutter_actor_set_anchor_point_from_gravity (icon, CLUTTER_GRAVITY_WEST);
-  clutter_actor_set_position (icon, height *0.15, height/2);
+  clutter_actor_set_position (icon, height * 0.15, height/2);
   clutter_actor_show (icon);
 
   group = clutter_group_new ();
@@ -602,6 +659,11 @@ make_item (const gchar *name, const gchar *icon_name, gint width, gint height)
   clutter_actor_set_position (label, 0, - (CAH (label)/2));
   clutter_actor_show (label);
 
+  if (cfg->new_theme)
+  {
+    clutter_actor_hide (icon);
+    clutter_actor_set_position (group, height * 0.30, height/2);
+  }
 
   return bg;
 }
@@ -612,7 +674,8 @@ on_toggle_clicked (ClutterActor *close,
                    LauncherIcon *icon)
 {
   LauncherIconPrivate *priv;
-  //LauncherConfig *cfg = launcher_config_get_default ();
+  LauncherConfig *cfg = launcher_config_get_default ();
+  gint ih;
   
   g_return_val_if_fail (LAUNCHER_IS_ICON (icon), FALSE);
   priv = icon->priv;
@@ -624,6 +687,8 @@ on_toggle_clicked (ClutterActor *close,
   {
     ClutterActor *bg, *item;
 
+    ih = (cfg->icon_height/4.5);
+
     priv->options = clutter_group_new ();
     clutter_container_add_actor (CLUTTER_CONTAINER (icon), priv->options);
     clutter_actor_set_size (priv->options, CAW (icon), CAH (icon));
@@ -633,25 +698,40 @@ on_toggle_clicked (ClutterActor *close,
     clutter_actor_set_opacity (priv->options, 0);
     clutter_actor_show (priv->options);
 
-    bg = item = launcher_util_texture_new_from_file (PKGDATADIR"/options.svg");
-    clutter_actor_set_size (bg, CAW (icon)*0.98, CAH (icon) * 0.70);
-    clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), bg);
-    clutter_actor_set_anchor_point_from_gravity (bg, CLUTTER_GRAVITY_NORTH);
-    clutter_actor_set_position (bg, CAW (icon)/2, CAH (icon) *0.25);
-    clutter_actor_show (bg);
+    if (cfg->new_theme)
+    {
+      bg = item = launcher_util_texture_new_from_file(cfg->catbg);
+      clutter_actor_set_size (bg, CAW (icon), CAH (icon));
+      clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), bg);
+      clutter_actor_set_anchor_point_from_gravity (bg, CLUTTER_GRAVITY_NORTH);
+      clutter_actor_set_position (bg, cfg->icon_width/2 + 1, 0);
+      clutter_actor_show (bg);
+    }
+    else
+    { 
+      bg = item = launcher_util_texture_new_from_file(cfg->options);
+      clutter_actor_set_size (bg, CAW (icon)*0.98, CAH (icon) - (ih*1.5));
+      clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), bg);
+      clutter_actor_set_anchor_point_from_gravity (bg, CLUTTER_GRAVITY_NORTH);
+      clutter_actor_set_position (bg, CAW (icon)/2, ih * 1.4);
+      clutter_actor_show (bg);
+    }
 
-    item = clutter_clone_texture_new (CLUTTER_TEXTURE (priv->texture));
-    clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), item);
-    clutter_actor_set_size (item, CAH (bg)/3.4, CAH (bg)/3.4);
-    clutter_actor_set_position (item, CAW (item) * 0.1, CAW (item) *0.1);
-    clutter_actor_show (item);
+    if (!cfg->new_theme)
+    {
+      item = clutter_clone_texture_new (CLUTTER_TEXTURE (priv->texture));
+      clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), item);
+      clutter_actor_set_size (item, ih, ih);
+      clutter_actor_set_position (item, ih * 0.1, ih * 0.1);
+      clutter_actor_show (item);
+    }
 
     item = make_item (_("Launch"), "applications-system", 
-                      CAW (bg), CAH (bg)/3);
+                      cfg->icon_width, ih*0.9);
     clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), item);
     clutter_actor_set_position (item, 
-                                CAW (icon) * 0.01,
-                                clutter_actor_get_y (bg));
+                                ih * 0.01,
+                                ih*1.5);
     clutter_actor_show (item);
     clutter_actor_set_reactive (item, TRUE);
     g_signal_connect (item, "button-release-event",
@@ -660,11 +740,11 @@ on_toggle_clicked (ClutterActor *close,
                       G_CALLBACK (on_enter), icon);
   
     item = make_item (_("Edit"), "gtk-properties",
-                      CAW (bg), CAH (bg)/3);
+                      cfg->icon_width, ih*0.9);
     clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), item);
     clutter_actor_set_position (item, 
-                                CAW (icon) * 0.01,
-                                clutter_actor_get_y (bg) + CAH (bg)/3);
+                                ih * 0.01,
+                                ih*2.5);
     clutter_actor_show (item);
     clutter_actor_set_reactive (item, TRUE);
     g_signal_connect (item, "button-release-event",
@@ -673,11 +753,11 @@ on_toggle_clicked (ClutterActor *close,
                       G_CALLBACK (on_enter), icon);
 
     item = make_item (_("Delete"), "gtk-delete",
-                      CAW (bg), CAH (bg)/3);
+                      cfg->icon_width, ih*0.9);
     clutter_container_add_actor (CLUTTER_CONTAINER (priv->options), item);
     clutter_actor_set_position (item, 
-                                CAW (icon) * 0.01,
-                                clutter_actor_get_y (bg) + ((CAH (bg)/3)*2));
+                                ih * 0.01,
+                                ih*3.5);
     clutter_actor_show (item);
     clutter_actor_set_reactive (item, TRUE);
     g_signal_connect (item, "button-release-event",
@@ -711,12 +791,22 @@ clip_label (ClutterLabel *label, const gchar *text, gint len, gint real_width)
 
   memcpy (buf, text, len+1);
 
-  lines = pango_layout_get_line_count (layout);  
+  if (buf[len/2] == ' ')
+    buf[len/2] = '\n';
+  else if (buf[len/2-1] == ' ')
+    buf[len/2-1] = '\n';
+  else if (buf[len/2+1] == ' ')
+    buf[len/2+1] = '\n';
+
+  clutter_label_set_text (label, buf);
+  layout = clutter_label_get_layout (label);
+   
+  lines = pango_layout_get_line_count (layout);
   while (lines > max_lines)
   {
     *g_utf8_prev_char (&buf[len]) = '\0';
     clutter_label_set_text (label, buf);
-    len -= 5;
+    len -= 1;
     layout = clutter_label_get_layout (label);
     lines = pango_layout_get_line_count (layout);
     touched = TRUE;
@@ -724,7 +814,7 @@ clip_label (ClutterLabel *label, const gchar *text, gint len, gint real_width)
 
   awidth = CLUTTER_UNITS_FROM_DEVICE (real_width);
   lwidth = CLUTTER_UNITS_FROM_PANGO_UNIT (pango_layout_get_width (layout));
-  while (lwidth > awidth && len > 12)
+  while (lwidth > awidth && len > 13)
   {
     *g_utf8_prev_char (&buf[len]) = '\0';
     clutter_label_set_text (label, buf);
@@ -748,6 +838,66 @@ clip_label (ClutterLabel *label, const gchar *text, gint len, gint real_width)
     return FALSE;
 }
 
+void
+launcher_icon_set_position (LauncherIcon *icon,
+                            gint          pos)
+{
+  LauncherIconPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
+  ClutterActor *bg, *bgv, *tex, *texv;
+  gint width = cfg->icon_width;
+  gint height = cfg->icon_height;
+ 
+  g_return_if_fail (LAUNCHER_IS_ICON (icon));
+  priv = icon->priv;
+
+  if (!cfg->new_theme)
+    return;
+
+  if (pos == 0)
+  {
+    tex = bg_corners[0];
+    texv = bgv_corners[0];
+  }
+  else if (pos == 5)
+  {
+    tex = bg_corners[1];
+    texv = bgv_corners[1];
+  }
+  else if (pos == 12)
+  {
+    tex = bg_corners[2];
+    texv = bgv_corners[2];
+  }
+  else if (pos ==  17)
+  {
+    tex = bg_corners[3];
+    texv = bgv_corners[3];
+  }
+  else
+  {
+    tex = bg_texture;
+    texv = bgv_texture;
+  }
+
+  bg = priv->bg;
+  clutter_clone_texture_set_parent_texture (CLUTTER_CLONE_TEXTURE (priv->bg),
+                                            CLUTTER_TEXTURE (tex));
+  clutter_actor_set_size (bg, width, height-1);
+  clutter_actor_set_position (bg, 1, 1);
+  clutter_actor_set_reactive (bg, TRUE);
+  clutter_actor_set_opacity (bg, BG_INACTIVE);
+  clutter_actor_show (bg);
+
+  bgv = priv->bgv;
+  clutter_clone_texture_set_parent_texture (CLUTTER_CLONE_TEXTURE (priv->bgv),
+                                            CLUTTER_TEXTURE (texv));
+  clutter_actor_set_size (bgv, width, height-1);
+  clutter_actor_set_position (bgv, 1, 1);
+  clutter_actor_set_opacity (bgv, BG_INACTIVE);
+  clutter_actor_show (bgv);
+}
+
 void 
 launcher_icon_set_application (LauncherIcon            *icon, 
                                LauncherMenuApplication *application)
@@ -755,37 +905,48 @@ launcher_icon_set_application (LauncherIcon            *icon,
   LauncherIconPrivate *priv;
   LauncherConfig *cfg = launcher_config_get_default ();
   GdkPixbuf *pixbuf;
-  ClutterActor *bg, *texture;
-  ClutterActor *label, *new;;
+  ClutterActor *bg, *bgv, *texture;
+  ClutterActor *label;
   ClutterColor color = { 0xff, 0xff, 0xff, 0xff };
   ClutterColor orange = { 0x00, 0x00, 0x00, 0xff };
   gint width = cfg->icon_width;
   gint height = cfg->icon_height;
   gint view_padding = cfg->iconview_padding;
-  gint icon_size = cfg->is_poulsbo ? height * 0.4 : height * 0.6;
- 
+  gint icon_size = cfg->icon_size;
+  gint iheight;
+   
   g_return_if_fail (LAUNCHER_IS_ICON (icon));
   priv = icon->priv;
 
   priv->app = application;
 
   /* bg */
-  bg = priv->bg = clutter_rectangle_new_with_color (&color);
+  if (cfg->new_theme)
+    bg = priv->bg = clutter_clone_texture_new (CLUTTER_TEXTURE (bg_texture));
+  else
+    bg = priv->bg = clutter_rectangle_new_with_color (&color);
   clutter_container_add_actor (CLUTTER_CONTAINER (icon), bg);
-  clutter_actor_set_size (bg, width - 1,height -1);
-  clutter_actor_set_position (bg, 0, 0);
+  clutter_actor_set_size (bg, width, height-1);
+  clutter_actor_set_position (bg, 1, 1);
   clutter_actor_set_reactive (bg, TRUE);
-  clutter_actor_set_opacity (bg, 50);
+  clutter_actor_set_opacity (bg, BG_INACTIVE);
   clutter_actor_show (bg);
-      
+
+  bgv = priv->bgv = clutter_clone_texture_new (CLUTTER_TEXTURE (bgv_texture));
+  clutter_container_add_actor (CLUTTER_CONTAINER (icon), bgv);
+  clutter_actor_set_size (bgv, width, height-1);
+  clutter_actor_set_position (bgv, 1, 1);
+  clutter_actor_set_opacity (bgv, BG_INACTIVE);
+  if (cfg->new_theme)clutter_actor_show (bgv);
+       
   /* Icon */
   pixbuf = launcher_menu_application_get_icon (application);
+  iheight = gdk_pixbuf_get_height (pixbuf);
   texture = priv->texture = clutter_texture_new_from_pixbuf (pixbuf);
-  clutter_actor_set_size (texture, icon_size, icon_size);
   clutter_actor_set_anchor_point_from_gravity (texture, CLUTTER_GRAVITY_NORTH);
   clutter_actor_set_position (texture, 
                               width/2,
-                              (cfg->is_poulsbo) ? height *0.3 :height *0.1);
+                              ((cfg->is_poulsbo && !cfg->is_tiger) ? height *0.2 :height *0.1)+((iheight==icon_size)?0:((icon_size-iheight)/2)));
   clutter_container_add_actor (CLUTTER_CONTAINER (icon), texture);
   clutter_actor_show (texture);
 
@@ -801,11 +962,12 @@ launcher_icon_set_application (LauncherIcon            *icon,
   clutter_label_set_text (CLUTTER_LABEL (label),
                           launcher_menu_application_get_name (application));
   clutter_actor_set_width (label, width);
+
   clutter_container_add_actor (CLUTTER_CONTAINER (icon), label);
   clutter_actor_set_position (label, 
                               (width-CAW(label))/2,
-                              clutter_actor_get_y (texture) + CAH(texture)
-          + (cfg->is_poulsbo ? (height *0.10) : (height * 0.05)));
+                              (height*0.15) + icon_size
+          + ((cfg->is_poulsbo && !cfg->is_tiger) ? (height *0.15) : (height * 0.15)));
   clutter_actor_show (label);
   priv->show_tooltip = clip_label (CLUTTER_LABEL (label),
                                    application->name,
@@ -841,7 +1003,7 @@ launcher_icon_set_application (LauncherIcon            *icon,
     clutter_actor_set_position (priv->tooltip, width/2, height);
   } 
 
-   /* 'New' indicator */
+   /* 'New' indicator 
   if (launcher_menu_application_is_new (application))
   {
     new = launcher_util_texture_new_from_named_icon ("emblem-new");
@@ -852,8 +1014,9 @@ launcher_icon_set_application (LauncherIcon            *icon,
     clutter_actor_set_position (new, 2*view_padding, 0);
     clutter_actor_show (new);
   }
+  */
 
-  priv->toggle = launcher_util_texture_new_from_file (PKGDATADIR"/info.svg");
+  priv->toggle = launcher_util_texture_new_from_file (cfg->info);
   clutter_container_add_actor (CLUTTER_CONTAINER (icon), priv->toggle);
   clutter_actor_set_size (priv->toggle, height*0.18, height*0.18);
   clutter_actor_set_position (priv->toggle, 
@@ -869,6 +1032,8 @@ launcher_icon_set_application (LauncherIcon            *icon,
   g_signal_connect (priv->toggle, "leave-event",
                     G_CALLBACK (on_leave), icon);
   
+  g_signal_connect (bg, "button-press-event", 
+                    G_CALLBACK (on_app_clicked), icon);
   g_signal_connect (bg, "button-release-event",
                     G_CALLBACK (on_app_clicked), icon);
   g_signal_connect (bg, "enter-event",
@@ -914,17 +1079,18 @@ void
 launcher_icon_set_focus (LauncherIcon *icon, gboolean has_focus)
 {
   LauncherIconPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
     
   g_return_if_fail (LAUNCHER_IS_ICON (icon));
   priv = icon->priv;
 
   if (has_focus)
   {
-    clutter_effect_fade (priv->temp, priv->bg, 130, NULL, NULL);
+    clutter_effect_fade (priv->temp, priv->bg, BG_ACTIVE, NULL, NULL);
   }
   else
   {
-    clutter_effect_fade (priv->temp, priv->bg, 50, NULL, NULL);
+    clutter_effect_fade (priv->temp, priv->bg, BG_INACTIVE, NULL, NULL);
   }
 }
 
@@ -947,7 +1113,16 @@ launcher_icon_launch (LauncherIcon *icon)
                          NULL, NULL);
 }
 
+void
+launcher_icon_reset_after_drag (LauncherIcon *icon)
+{
+  LauncherConfig *cfg = launcher_config_get_default ();
 
+  g_return_if_fail (LAUNCHER_IS_ICON (icon));
+
+  clutter_actor_set_opacity (icon->priv->bg, BG_ACTIVE);
+  clutter_actor_set_opacity (icon->priv->bgv, BG_INACTIVE);
+}
 
 /* GObject stuff */
 static void
@@ -990,6 +1165,7 @@ static void
 launcher_icon_init (LauncherIcon *icon)
 {
   LauncherIconPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
   ClutterAlpha *alpha;
   
   priv = icon->priv = LAUNCHER_ICON_GET_PRIVATE (icon);
@@ -999,16 +1175,131 @@ launcher_icon_init (LauncherIcon *icon)
 
   if (!CLUTTER_IS_ACTOR (bg_texture))
   {
-    GdkPixbuf *temp;
+    ClutterActor *stage;
+    GdkPixbuf *temp, *temp1;
+    gint width, height, corner = 15;
 
-    temp = gdk_pixbuf_new_from_file (PKGDATADIR"/icon.svg", NULL);
+    stage = clutter_stage_get_default ();
+
+    temp = gdk_pixbuf_new_from_file (cfg->catbg, NULL);
     bg_texture = clutter_texture_new_from_pixbuf (temp);
     clutter_container_add_actor (CLUTTER_CONTAINER (clutter_stage_get_default()), 
                                  bg_texture);
     clutter_actor_realize (bg_texture);
     g_object_unref (temp);
+
+    if (!cfg->new_theme)
+    {
+      bg_corners[0]=bg_corners[1] = bg_corners[2] = bg_corners[3] = bg_texture;
+      bgv_corners[0]=bgv_corners[1]=bgv_corners[2]=bgv_corners[3]=bgv_texture;
+    }
+    else
+    {
+      temp =gdk_pixbuf_new_from_file (PKGDATADIR"/clarity-theme/catbgcorners.svg",
+                                    NULL);
+      width = gdk_pixbuf_get_width (temp);
+      height = gdk_pixbuf_get_height (temp);
+
+      temp1 = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
+                            width-corner, height-corner);
+      gdk_pixbuf_copy_area (temp, 0, 0, width-corner, height-corner, temp1, 0, 0);
+      bg_corners[0] = clutter_texture_new_from_pixbuf (temp1);
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), bg_corners[0]);
+      clutter_actor_realize (bg_corners[0]);
+      g_object_unref (temp1);
+
+      temp1 = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
+                            width-corner, height-corner);
+      gdk_pixbuf_copy_area (temp, 
+                            corner, 0, width-corner, height-corner, 
+                            temp1, 0, 0);
+      bg_corners[1] = clutter_texture_new_from_pixbuf (temp1);
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), bg_corners[1]);
+      clutter_actor_realize (bg_corners[1]);
+      g_object_unref (temp1);
+
+      temp1 = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
+                            width-corner, height-corner);
+      gdk_pixbuf_copy_area (temp, 
+                          0, corner, width-corner, height-corner, 
+                            temp1, 0, 0);
+      bg_corners[2] = clutter_texture_new_from_pixbuf (temp1);
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), bg_corners[2]);
+      clutter_actor_realize (bg_corners[2]);
+      g_object_unref (temp1);
+  
+      temp1 = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
+                              width-corner, height-corner);
+      gdk_pixbuf_copy_area (temp, 
+                            corner, corner, width-corner, height-corner, 
+                            temp1, 0, 0);
+      bg_corners[3] = clutter_texture_new_from_pixbuf (temp1);
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), bg_corners[3]);
+      clutter_actor_realize (bg_corners[3]);
+      g_object_unref (temp1);
+
+      g_object_unref (temp);
+
+      temp =gdk_pixbuf_new_from_file(PKGDATADIR"/clarity-theme/catbgcornersv.svg",
+                                      NULL);
+      width = gdk_pixbuf_get_width (temp);
+      height = gdk_pixbuf_get_height (temp);
+
+      temp1 = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
+                            width-corner, height-corner);
+      gdk_pixbuf_copy_area (temp, 0, 0, width-corner, height-corner, temp1, 0, 0);
+      bgv_corners[0] = clutter_texture_new_from_pixbuf (temp1);
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), bgv_corners[0]);
+      clutter_actor_realize (bgv_corners[0]);
+      g_object_unref (temp1);
+  
+      temp1 = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
+                              width-corner, height-corner);
+      gdk_pixbuf_copy_area (temp, 
+                            corner, 0, width-corner, height-corner, 
+                            temp1, 0, 0);
+      bgv_corners[1] = clutter_texture_new_from_pixbuf (temp1);
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), bgv_corners[1]);
+      clutter_actor_realize (bgv_corners[1]);
+      g_object_unref (temp1);
+
+      temp1 = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
+                              width-corner, height-corner);
+      gdk_pixbuf_copy_area (temp, 
+                            0, corner, width-corner, height-corner, 
+                            temp1, 0, 0);
+      bgv_corners[2] = clutter_texture_new_from_pixbuf (temp1);
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), bgv_corners[2]);
+      clutter_actor_realize (bgv_corners[2]);
+      g_object_unref (temp1);
+  
+      temp1 = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
+                              width-corner, height-corner);
+      gdk_pixbuf_copy_area (temp, 
+                            corner, corner, width-corner, height-corner, 
+                            temp1, 0, 0);
+      bgv_corners[3] = clutter_texture_new_from_pixbuf (temp1);
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), bgv_corners[3]);
+      clutter_actor_realize (bgv_corners[3]);
+      g_object_unref (temp1);
+  
+      g_object_unref (temp);
+    }
   }
 
+  if (!CLUTTER_IS_ACTOR (bgv_texture))
+  {
+    GdkPixbuf *temp;
+
+    temp = gdk_pixbuf_new_from_file (cfg->catbgv, NULL);
+    bgv_texture = clutter_texture_new_from_pixbuf (temp);
+    clutter_container_add_actor (CLUTTER_CONTAINER (clutter_stage_get_default()), 
+                                 bgv_texture);
+    clutter_actor_realize (bgv_texture);
+    g_object_unref (temp);
+  }
+
+
   priv->slow_time = launcher_util_timeline_new_slow ();
   alpha = clutter_alpha_new_full (priv->slow_time,
                                   clutter_sine_inc_func,
