@@ -52,10 +52,13 @@ G_DEFINE_TYPE_WITH_CODE (LauncherIconview,
   LAUNCHER_TYPE_ICONVIEW, \
   LauncherIconviewPrivate))
 
-#define BG_PADDING 4
+#define BG_PADDING ((cfg->bg_padding))
 
 static ClutterActor *iconviewbg      = NULL;
+static GdkPixbuf    *iconviewbg_p    = NULL;
 static ClutterActor *shadowbg        = NULL;
+static GList *icons = NULL;
+static gint n_icons = 0;
 
 struct _LauncherIconviewPrivate
 {
@@ -239,6 +242,7 @@ on_drag_finished (ClutterDragServer *server,
   }
   
   clutter_actor_set_opacity (priv->drag_icon, 255);
+  launcher_icon_reset_after_drag (LAUNCHER_ICON (priv->drag_icon));
   
   for (i = priv->icons; i; i = i->next)
   {
@@ -273,6 +277,34 @@ on_drag_finished (ClutterDragServer *server,
   priv->drag_context = NULL;
   priv->old_pos = 0;
   priv->drag_icon = NULL;
+
+  {
+    GList *i;
+    gdouble diff = 0.0;
+    gint rows = 0;
+    gint j = 0, k = 0;
+
+    if (TIDY_IS_ADJUSTMENT (priv->adjust))
+      diff = tidy_adjustment_get_value (priv->adjust);
+
+    rows = diff / cfg->icon_height;
+
+    if ((rows+2) > n_icons/6)
+      rows -= 2;
+
+    for (i = priv->icons; i; i = i->next)
+    {
+      if (j < (rows * 6))
+        ;
+      else
+      {
+        if (i && i->data && LAUNCHER_IS_ICON (i->data))
+          launcher_icon_set_position (LAUNCHER_ICON (i->data), k);
+        k++;
+      }
+      j++;
+    }
+  }
 }
 
 static void
@@ -335,6 +367,7 @@ static void
 on_drag_started (ClutterDragServer *server, LauncherIconview *view)
 {
   LauncherIconviewPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
   ClutterActor *context;
   gint icon_height = (launcher_config_get_default ())->icon_height;
   
@@ -351,7 +384,7 @@ on_drag_started (ClutterDragServer *server, LauncherIconview *view)
 
   priv->old_pos = g_list_index (priv->icons, priv->drag_icon);
 
-  priv->drag_sep = launcher_util_texture_new_from_file (PKGDATADIR"/sep.svg");
+  priv->drag_sep = launcher_util_texture_new_from_file (cfg->sep);
   clutter_container_add_actor (CLUTTER_CONTAINER (clutter_stage_get_default ()),
                                priv->drag_sep);
   clutter_actor_set_size (priv->drag_sep, 
@@ -449,6 +482,29 @@ on_scroll_event (ClutterActor       *actor,
 
   tidy_adjustment_set_value (adjust, diff);
 
+  {
+    GList *i;
+    gint rows = 0;
+    gint j = 0, k = 0;
+
+    rows = diff / cfg->icon_height;
+
+    if ((rows+2) > n_icons/6)
+      rows -= 2;
+
+    for (i = icons; i; i = i->next)
+    {
+      if (j < (rows * 6))
+        ;
+      else
+      {
+        launcher_icon_set_position (LAUNCHER_ICON (i->data), k);
+        k++;
+      }
+      j++;
+    }
+  }
+
   return TRUE;
 }
 
@@ -537,6 +593,7 @@ foldout (LauncherIconview *view)
       app= (LauncherMenuApplication*)g_object_get_data (G_OBJECT (icon), "app");
       
       launcher_icon_set_application (icon, app);
+      launcher_icon_set_position (icon, i);
     }
   }
   
@@ -573,6 +630,7 @@ foldout (LauncherIconview *view)
                                                            "app");
       
         launcher_icon_set_application (icon, app);
+        launcher_icon_set_position (icon, i);
       }
     }
      
@@ -580,7 +638,7 @@ foldout (LauncherIconview *view)
       clutter_effect_fade (priv->temp, priv->scroll, 255, NULL, NULL);
 
     clutter_actor_remove_clip (priv->bg);
-    clutter_actor_remove_clip (priv->shadow); 
+    clutter_actor_remove_clip (priv->shadow);    
     launcher_util_start_input ();
     return FALSE;
   }
@@ -663,11 +721,12 @@ launcher_iconview_set_category (LauncherIconview     *view,
   ClutterFocusManager *manager = CLUTTER_FOCUS_MANAGER (clutter_focus_manager_get_default ());
   TidyAdjustment *adjustment;
   GList *l;
-  gint xoffset, yoffset, i = 0, rows = 0;
+  gint xoffset, yoffset, i = 0, rows = 0, j = 0;
   gint app_cols = cfg->iconview_cols;
   gint view_width = cfg->iconview_width;
   gint view_height = cfg->iconview_height;
   gint icon_height = cfg->icon_height;
+  gint cat_height = cfg->cat_height;
 
   g_return_if_fail (LAUNCHER_IS_ICONVIEW (view));
   g_return_if_fail (cat);
@@ -677,23 +736,22 @@ launcher_iconview_set_category (LauncherIconview     *view,
     return;
 
   shadow = launcher_util_texture_new_from_file (PKGDATADIR"/shadow.svg");
-  clutter_container_add_actor (CLUTTER_CONTAINER (view), shadow);
-  shadow = priv->shadow = tidy_texture_frame_new (CLUTTER_TEXTURE (shadow), 
-                                                  20, 20, 20, 20);
+  priv->shadow = shadow;
   clutter_container_add_actor (CLUTTER_CONTAINER (view), shadow);
   clutter_actor_set_size (shadow, view_width+8+(2*BG_PADDING), 
                           view_height+8+(2*BG_PADDING));
   clutter_actor_set_position (shadow, -4-BG_PADDING, -4-BG_PADDING);
+  clutter_actor_set_opacity (shadow, cfg->new_theme ? 0 : 200);
   clutter_actor_show (shadow);
  
-  priv->bg = tidy_texture_frame_new (CLUTTER_TEXTURE (iconviewbg),
-                                BG_PADDING, BG_PADDING, BG_PADDING, BG_PADDING);
+//  priv->bg = tidy_texture_frame_new (CLUTTER_TEXTURE (iconviewbg),
+  //                            BG_PADDING, BG_PADDING, BG_PADDING, BG_PADDING);
+  priv->bg = clutter_texture_new_from_pixbuf (iconviewbg_p);
   clutter_container_add_actor (CLUTTER_CONTAINER (view), priv->bg);
   clutter_actor_set_size (priv->bg,
-                          view_width + (2*BG_PADDING),
-                          view_height + (2*BG_PADDING));
+                          view_width+1 + (2*BG_PADDING),
+                          view_height+1 + (2*BG_PADDING));
   clutter_actor_set_position (priv->bg, -BG_PADDING, -BG_PADDING);
-  clutter_actor_set_opacity (priv->bg, 220);
   clutter_actor_show (priv->bg);
   clutter_actor_set_reactive (priv->bg, TRUE);
   g_signal_connect (priv->bg, "button-release-event",
@@ -723,8 +781,10 @@ launcher_iconview_set_category (LauncherIconview     *view,
     if (first_run)
       g_object_set_data (G_OBJECT (actor), "app", app);
     else
+    {
       launcher_icon_set_application (LAUNCHER_ICON (actor), app);
-    
+      launcher_icon_set_position (LAUNCHER_ICON (actor), j);
+    }
     clutter_container_add_actor (CLUTTER_CONTAINER (priv->grid), actor);
     clutter_actor_set_size (actor, cfg->icon_width, cfg->icon_height);
     clutter_actor_set_position (actor, xoffset, yoffset);
@@ -751,8 +811,10 @@ launcher_iconview_set_category (LauncherIconview     *view,
       xoffset += cfg->icon_width;
       i++;
     }
-
+    j++;
   }
+  n_icons = j;
+  icons = priv->icons;
 
   clutter_actor_set_height (CLUTTER_ACTOR (priv->grid), 
                             (rows +1) * icon_height);
@@ -770,7 +832,7 @@ launcher_iconview_set_category (LauncherIconview     *view,
                                 3 * icon_height);
     priv->adjust = adjustment;
 
-    tex = launcher_util_texture_new_from_file (PKGDATADIR"/handle.svg");
+    tex = launcher_util_texture_new_from_file (cfg->handle);
     clutter_container_add_actor (CLUTTER_CONTAINER (view), tex);
     
     frame = tidy_texture_frame_new (CLUTTER_TEXTURE (tex), 32, 3, 32, 3);
@@ -779,7 +841,7 @@ launcher_iconview_set_category (LauncherIconview     *view,
                       G_CALLBACK (on_scroll_event), adjustment); 
     scroll = priv->scroll = tidy_scroll_bar_new_with_handle (adjustment, frame);
 
-    tex = launcher_util_texture_new_from_file (PKGDATADIR"/scrollbar.svg");
+    tex = launcher_util_texture_new_from_file (cfg->scrollbar);
     clutter_container_add_actor (CLUTTER_CONTAINER (view), tex);    
     
     frame = tidy_texture_frame_new (CLUTTER_TEXTURE (tex), 30, 5, 30, 5);
@@ -850,12 +912,14 @@ launcher_iconview_set_category (LauncherIconview     *view,
   /* Add the 'add' button */
   priv->add = launcher_add_new ();
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), priv->add);
-  clutter_actor_set_size (priv->add, cfg->cat_height/3, cfg->cat_height/3);
+  clutter_actor_set_size (priv->add, cat_height/4, cat_height/4);
   clutter_actor_set_anchor_point_from_gravity (priv->add, 
                                                CLUTTER_GRAVITY_CENTER);
   clutter_actor_set_position (priv->add, 
-                              CSW()-(CAW(priv->add)),
-                              CSH()-(CAH(priv->add)));
+                              CSW()-((CSW()/8)/2),
+                              ((CSH()/2)-(cfg->iconview_height/2))
+                                +cfg->cat_height/2 + PANEL_HEIGHT/2
+                                + view_height - (cat_height/8));
   clutter_actor_show (priv->add);
   g_signal_connect (priv->add, "clicked",
                     G_CALLBACK (on_add_clicked), view);
@@ -866,7 +930,7 @@ launcher_iconview_set_category (LauncherIconview     *view,
   if (first_run)
   {
     priv->count = 1;
-    priv->tag = g_timeout_add (200, (GSourceFunc)foldout, view);
+    priv->tag = g_timeout_add (100, (GSourceFunc)foldout, view);
   }
   else
   {
@@ -1050,6 +1114,7 @@ static void
 launcher_iconview_init (LauncherIconview *iconview)
 {
   LauncherIconviewPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
   ClutterDragServer *server = clutter_drag_server_get_default ();
   ClutterAlpha *alpha;
 
@@ -1059,10 +1124,16 @@ launcher_iconview_init (LauncherIconview *iconview)
   priv->count = priv->tag = 0;
 
   if (!CLUTTER_IS_TEXTURE (iconviewbg))
-    iconviewbg = launcher_util_texture_new_from_file (PKGDATADIR"/iconviewbg.svg");
+    iconviewbg = launcher_util_texture_new_from_file (cfg->iconviewbg);
   else
     g_object_ref (iconviewbg);
 
+  if (!GDK_IS_PIXBUF (iconviewbg_p))
+  {
+    iconviewbg_p = gdk_pixbuf_new_from_file (cfg->iconviewbg, NULL);
+    g_object_ref (iconviewbg_p);
+  }
+
   if (!CLUTTER_IS_TEXTURE (shadowbg))
     shadowbg = launcher_util_texture_new_from_file (PKGDATADIR"/shadow.svg");
   else
