@@ -639,7 +639,7 @@ sort_categories (LauncherMenu *menu)
     {
       LauncherMenuCategory *cat = c->data;
 
-      if (path && cat->path && strcmp (path, cat->path) == 0)
+      if (path && cat->path && g_strstr_len (cat->path, -1, path))
       {
         priv->categories = g_list_remove (priv->categories, cat);
         priv->categories = g_list_insert (priv->categories, cat, i);
@@ -721,7 +721,7 @@ sort_applications (LauncherMenu *menu, LauncherMenuCategory *cat)
     {
       LauncherMenuApplication *app = a->data;
 
-      if (path && app->path && strcmp (path, app->path) == 0)
+      if (path && app->path && g_strstr_len (app->path, -1, path))
       {
         cat->applications = g_list_remove (cat->applications, app);
         cat->applications= g_list_insert (cat->applications, app, i);
