@@ -162,6 +162,36 @@ strip_extension (const char *file)
         return stripped;
 }
 
+static GdkPixbuf *
+constrain_size (GdkPixbuf *pixbuf)
+{
+#define MAX_WIDTH ((67))
+  static LauncherConfig *cfg = NULL;
+  GdkPixbuf *temp = NULL;
+  gint width;
+  
+  if (cfg == NULL)
+    cfg = launcher_config_get_default ();
+
+  width = gdk_pixbuf_get_width (pixbuf);
+
+  if (width > MAX_WIDTH)
+  {
+    gint height;
+
+    height = gdk_pixbuf_get_height (pixbuf);
+    
+    temp = pixbuf;
+
+    pixbuf = gdk_pixbuf_scale_simple (temp, 
+                                      MAX_WIDTH,
+    (gint)(((gfloat)height/width) * (MAX_WIDTH)),
+                                      GDK_INTERP_BILINEAR);
+    g_object_unref (temp);
+  }
+  return pixbuf;
+}
+
 /* Gets the pixbuf from a desktop file's icon name. Based on the same function
  * from matchbox-desktop
  */
@@ -189,7 +219,7 @@ get_icon (const gchar *name, guint size)
   {
     if (g_file_test (name, G_FILE_TEST_EXISTS))
     {
-      pixbuf = gdk_pixbuf_new_from_file_at_scale (name, size, size, 
+      pixbuf = gdk_pixbuf_new_from_file_at_scale (name, -1, size, 
                                                   TRUE, &error);
       if (error)
       {
@@ -197,38 +227,66 @@ get_icon (const gchar *name, guint size)
         g_error_free (error);
         error = NULL;
      }
-      return pixbuf;
+      return constrain_size (pixbuf);
     } 
   }
 
   stripped = strip_extension (name);
-  
-  pixbuf = gtk_icon_theme_load_icon (theme,
-                                     stripped,
-                                     size,
-                                     0, &error);
-  if (error)
-  {   
-    /*g_warning ("Error loading icon: %s\n", error->message);*/
-    g_error_free (error);
-    error = NULL;
+
+  {  
+    GtkIconInfo *info;
+    const gchar *filename;
+    
+    info = gtk_icon_theme_lookup_icon (theme, stripped, size, 0);
+
+    if (info)
+    {
+      filename = gtk_icon_info_get_filename (info);
+      
+      if (filename)
+      {
+        pixbuf = gdk_pixbuf_new_from_file_at_scale (filename, -1, size, 
+                                                  TRUE, &error);
+        if (error)
+        {
+          /*g_warning ("Error loading icon: %s\n", error->message);*/
+          g_error_free (error);
+          error = NULL;
+        }
+      }
+      gtk_icon_info_free (info);
+    }
   }
   
+  if (!GDK_IS_PIXBUF (pixbuf))
+  {
+    pixbuf = gtk_icon_theme_load_icon (theme,
+                                       stripped,
+                                       size,
+                                       0, &error);
+    if (error)
+    {   
+      /*g_warning ("Error loading icon: %s\n", error->message);*/
+      g_error_free (error);
+      error = NULL;
+    }
+  }
   /* Always try and send back something */
   if (!GDK_IS_PIXBUF (pixbuf))
     pixbuf = gtk_icon_theme_load_icon (theme, "application-x-executable",
-                                       size, 0, NULL);
+                                       size, 
+                                       0, NULL);
 
   if (GDK_IS_PIXBUF (pixbuf))
   {  
     width = gdk_pixbuf_get_width (pixbuf);
     height = gdk_pixbuf_get_height (pixbuf);
 
-    if (width != size || height != size)
+    if (height != size && 0)
     {
       GdkPixbuf *temp = pixbuf;
       pixbuf = gdk_pixbuf_scale_simple (temp, 
-                                      size,
+                                      (gint)((float)width/height)*size,
                                       size,
                                       GDK_INTERP_HYPER);
       g_object_unref (temp);
